
# Slot: typeof


Names a parent type

URI: [meta:typeof](https://w3id.org/biolink/biolinkml/meta/typeof)

## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)
